#include "stdafx.h"

#include "stexture.h"
#include <d3dx9tex.h>
#include <assert.h>

CSTexture::CSTexture(void)
{
	m_pTexture = NULL;
	m_bLocked = FALSE;

}

CSTexture::~CSTexture(void)
{
}


HRESULT CSTexture::GetInformation()
{
	if( FAILED( Lock() ) )
		return E_FAIL;

	UnLock();

	// ؽ ũ⸦  ۾
	D3DSURFACE_DESC desc;
	m_pTexture->GetLevelDesc( 0, &desc );

	m_dwHeight = desc.Height;
	m_dwWidth  = desc.Width;

	return S_OK;
}

HRESULT CSTexture::Load( LPDIRECT3DDEVICE9 pDevice, LPSTR szFilename )
{
	if( m_pTexture != NULL )
		return E_FAIL;

	D3DXCreateTextureFromFile( pDevice, szFilename, &m_pTexture );	

	return GetInformation();
}

HRESULT CSTexture::Create( LPDIRECT3DDEVICE9 pDevice, UINT Width, UINT Height, UINT Levels, 
						   DWORD Usage, D3DFORMAT Format, D3DPOOL Pool )
{
	assert( !m_pTexture );
	pDevice->CreateTexture( Width, Height, Levels, Usage, Format, Pool, &m_pTexture, NULL );

	return GetInformation();
}

void CSTexture::Release()
{
	SAFE_RELEASE(m_pTexture);
}

HRESULT CSTexture::SetTexture( LPDIRECT3DDEVICE9 pDevice )
{
	return pDevice->SetTexture( 0, m_pTexture );
}


void CSTexture::PutPixel( int x, int y, D3DCOLOR Color )
{
	DWORD *p = GetBitsPointer();

	p += ( y * ( m_dwPitch >> 2 ) ) + x ;

	*p = Color;

}

HRESULT CSTexture::Lock()
{
	if( m_bLocked )
		return S_OK;

	if( !m_pTexture )
		return E_FAIL;

	D3DLOCKED_RECT LockInfo;

	HRESULT hr = m_pTexture->LockRect( 0, &LockInfo, 0, NULL );

    
	if( FAILED( hr ) )
		return E_FAIL;

	m_pBits = (DWORD*)LockInfo.pBits;
	m_dwPitch= (DWORD)LockInfo.Pitch;

	m_bLocked = TRUE;

	return S_OK;
}

void CSTexture::UnLock()
{
	if( !m_bLocked )
		return;

	m_pTexture->UnlockRect( 0 );

	m_bLocked = FALSE;
}

void CSTexture::Clear( D3DCOLOR Color )
{
	Lock();
	DWORD* pBits = GetBitsPointer();

	int Size = m_dwPitch * m_dwHeight;

	memset( pBits, Color, Size );
}


__inline DWORD* CSTexture::GetBitsPointer()
{
	return m_pBits;
}

